import 'package:cresce_ui/cresce_ui.dart';
import 'package:flutter/material.dart';

class ButtonState {
  final TextStyle labelStyle;
  final Color backgroundColor;
  final Color borderColor;
  final Curve curve;
  final Duration animationDuration;

  ButtonState({
    required this.labelStyle,
    required this.backgroundColor,
    required this.borderColor,
    required this.curve,
    required this.animationDuration,
  });
}

class DisabledButtonState extends ButtonState {
  DisabledButtonState()
      : super(
          labelStyle: CTextStyles.fieldSecondaryVar2,
          backgroundColor: CColors.secondary,
          borderColor: CColors.secondaryVar2,
          curve: Curves.linear,
          animationDuration: const Duration(milliseconds: 100),
        );
}

class UntappedButtonState extends ButtonState {
  UntappedButtonState()
      : super(
          labelStyle: CTextStyles.fieldPrimary,
          backgroundColor: CColors.secondary,
          borderColor: CColors.primary,
          curve: Curves.easeInToLinear,
          animationDuration: const Duration(milliseconds: 250),
        );
}

class TappedButtonState extends ButtonState {
  TappedButtonState()
      : super(
          labelStyle: CTextStyles.fieldSecondary,
          backgroundColor: CColors.primary,
          borderColor: CColors.primary,
          curve: Curves.easeOut,
          animationDuration: const Duration(milliseconds: 50),
        );
}

class UntappedAlertButtonState extends ButtonState {
  UntappedAlertButtonState()
      : super(
          labelStyle: CTextStyles.fieldAlert,
          backgroundColor: CColors.secondary,
          borderColor: CColors.alert,
          curve: Curves.linear,
          animationDuration: const Duration(milliseconds: 100),
        );
}

class TappedAlertButtonState extends ButtonState {
  TappedAlertButtonState()
      : super(
          labelStyle: CTextStyles.fieldSecondary,
          backgroundColor: CColors.alert,
          borderColor: CColors.alert,
          curve: Curves.linear,
          animationDuration: const Duration(milliseconds: 100),
        );
}
