part of cresce_ui;

class CInputMoney extends StatelessWidget {
  final String label;
  final void Function(double value)? onChanged;
  final Locale? locale;
  final double? initialValue;

  const CInputMoney({
    Key? key,
    required this.label,
    this.onChanged,
    this.locale,
    this.initialValue = 0.0,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return CInputText(
      label: label,
      keyboardType: TextInputType.number,
      inputFormatters: [MoneyTextInputFormatter(locale)],
      initialValue: formatCurrency(initialValue),
      onChanged: (value) => onChanged?.call(getValue(value)),
    );
  }

  String formatCurrency(double? value) {
    return NumberFormat.simpleCurrency(
      locale: (locale ?? const Locale('en', 'US')).toString(),
      decimalDigits: 2,
    ).format(value);
  }
}

double getValue(String value) {
  if (value.isEmpty) return 0.0;
  String newText = value.replaceAll(RegExp('[^0-9]'), '');
  return int.parse(newText) / 100;
}

class MoneyTextInputFormatter implements TextInputFormatter {
  final Locale? locale;

  MoneyTextInputFormatter(this.locale);

  @override
  TextEditingValue formatEditUpdate(
      TextEditingValue oldValue, TextEditingValue newValue) {
    var value = newValue.text;
    if (value.isEmpty) {
      return const TextEditingValue(text: '');
    }

    if (locale != null) {
      var formatted = formatCurrency(value);
      return TextEditingValue(
        text: formatted,
        selection: TextSelection.collapsed(
          offset: calcOffset(formatted),
        ),
      );
    }

    return TextEditingValue(
      text: newValue.text,
      selection: TextSelection.collapsed(offset: newValue.text.length),
    );
  }

  String formatCurrency(String value) {
    return NumberFormat.simpleCurrency(
      locale: locale.toString(),
      decimalDigits: 2,
    ).format(getValue(value));
  }

  int calcOffset(String formatted) {
    if (formatted.startsWith('\$')) return formatted.length;
    return formatted.length - 2;
  }
}
